#ifndef DIRLISTBOX_H
#define DIRLISTBOX_H

class DirList;

class DirListBox : public FXDialogBox
{
    FXDECLARE(DirListBox)

private:
    DirListBox()
    {}

protected:
    DirList *dirtree;

public:

public:
    enum{
        ID_DIRECTORY=FXDialogBox::ID_LAST,
		ID_DIRLIST_BOX,
        ID_LAST
    };

public:
    
	// Construct a directory box list
	DirListBox(FXWindow *win);

    // Create server-side resources
    virtual void create();

	// Destructor
    virtual ~DirListBox();

    FXuint execute();
	long onExpand(FXObject*,FXSelector,void* ptr);
    FXString getPath();
    void setPath(const FXString &path);

    
};

#endif
